<?php
$page_title = "Notice Preview";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					&nbsp;
				</div>
				&nbsp;
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
					<?php include_once('template/base_nav.php'); ?>
					<form id="acForm" action="" method="post">
						<article>
							<div class="article-heading">
								<h2><?php echo $page_title; ?></h2>
							</div>
							<?php $this -> echoMessage(); ?>
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w20p">
									<col class="w80p">
								</colgroup>
								<tr>
									<th>Preview</th>
									<td>
										<?php $this -> echoBody(); ?>
									</td>
								</tr>
								<tr>
									<th>HTML</th>
									<td>
										<textarea name="body" id="body" rows="20" class="w100p"><?php $this -> echoBody(); ?></textarea>
									</td>
								</tr>
							</table>
							<p class="calign">
								<?php $this -> echoParam(); ?>
							</p>
							<div class="article-bottom">
							</div>
						</article>
						<input type="hidden" value="" id="type" name="type" />
						<input type="hidden" value="<?php $this -> echoExposeTime(); ?>" id="expose_time" name="expose_time" />
						<input type="hidden" value="<?php $this -> echoTitle(); ?>" id="title" name="title" />
						<input type="hidden" value="<?php $this -> echoNId(); ?>" id="n_id" name="n_id" />
						<input type="hidden" value="1" id="status" name="status" />
						<?php $this -> echoTranslationData("/news", "confirm") ?>
					</form>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
		<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/news.js"></script>
</body>
</html>
